@@ -337,7 +337,9 @@ function paraselene_action(tag,obj){
 }
 
 function paraselene_url_check(url,param){
-	var jsession=url.split(";");
+	if(!navigator.cookieEnabled)	return undefined;
+	var jsession=url.split(";jsessionid");
+	if(jsession.length>1)	return undefined;
 	url=jsession[0];
 	var url_test=url.split("?");
 	url=url_test[0];
