@@ -88,9 +88,11 @@ public abstract class Output {
 		char[]	ch = str.toCharArray();
 		StringBuilder	buf = new StringBuilder();
 		for ( int i = 0; i < ch.length; i++ ) {
+/*
 			if ( ch[i] == '\n' || ch[i] == '\r' ) {
 				continue;
 			}
+*/
 			buf.append( ch[i] );
 		}
 		return buf.toString();
@@ -116,7 +118,7 @@ public abstract class Output {
 			bw = new BufferedWriter(
 				new OutputStreamWriter(
 				new FileOutputStream( file ), Param.SOURCE_ENCODE.get() ) );
-			bw.write( SourceHead.getHead() );
+			bw.write( SourceHead.getHead( file ) );
 			for ( int i = 0; i < str.length; i++ ) {
 				if ( str[i] == '#' ) {
 					i++;
