@@ -25,6 +25,7 @@ public class Closure extends Forward implements AjaxForward {
 		public int getID(){ return -1; }
 		public PageID getPageID( int id ){ return null; }
 		public PageFactory getPageFactory(){ return null; }
+		public String toString() { return "Closure.CLOSE page"; }
 	};
 
 	private static PageID getLastPage( Page myself, History history ) {
@@ -78,5 +79,12 @@ public class Closure extends Forward implements AjaxForward {
 		if ( from.getPopupType() != null )	return true;
 		return next.getID() == getLastPage( from, req.getHistory( from.getHistoryKey() ) );
 	}
+
+	public String toString() {
+		StringBuilder	buf = new StringBuilder( "Closure:" );
+		buf = buf.append( close_page.getID().toString() );
+		buf = buf.append( "/" ).append( close_page.getUniqueKey() );
+		return buf.toString();
+	}
 }
 
