@@ -99,8 +99,9 @@ class SessionData implements Serializable, HttpSessionBindingListener {
 
 	public void valueBound( HttpSessionBindingEvent ev ) {}
 	public void valueUnbound( HttpSessionBindingEvent ev ) {
-		hist.drop();
+		if ( !planed_clear )	hist.drop();
 	}
+	boolean	planed_clear = false;
 }
 
 
