@@ -200,7 +200,8 @@ public abstract class Supervisor extends HttpServlet {
 			uri = holder.response.encodeURL( URIValue.encode( uri, enc ) );
 		}
 		else {
-			if ( holder.sv.getPageFactory().isAlias( uri ) && to_key != HistorySet.ROOT ) {
+			boolean	alias_f = holder.sv.getPageFactory().isAlias( uri );
+			if ( alias_f && to_key != HistorySet.ROOT ) {
 				StringBuilder	buf = new StringBuilder( TransactionSequencer.SELENE[5] );
 				buf = buf.append( "." );
 				buf = buf.append( Integer.toString( to_key, Character.MAX_RADIX ) );
@@ -210,7 +211,7 @@ public abstract class Supervisor extends HttpServlet {
 				buf = buf.append( uri );
 				uri = buf.toString();
 			}
-			if ( isMyHost( uri ) ) {
+			if ( !alias_f && isMyHost( uri ) ) {
 				uri = holder.response.encodeURL( URIValue.encode( uri, enc ) );
 			}
 			else {
