@@ -39,7 +39,7 @@ public class Tag extends HTMLPart {
 	private ArrayList<Tag>		tag_only = new ArrayList<Tag>();
 	private boolean nest_f = false;
 	private boolean visible_f = true;
-	private boolean dirty_f = true;
+	private volatile boolean dirty_f = true;
 	private short[]	location_no = new short[]{ 0 };
 
 	private static String	VALUE = "value";
@@ -55,14 +55,41 @@ public class Tag extends HTMLPart {
 		return embed_page;
 	}
 
-	/**
-	 * 更新された事を通知する。
-	 */
-	public void setModify() {
-		dirty_f = true;
+	private void set_modify() {
 		if ( getAttribute( "id" ) == null ) {
-			getOuterTag().setModify();
+			Tag	out = getOuterTag();
+			if ( out != null ) {
+				out.set_modify();
+				return;
+			}
 		}
+		dirty_f = true;
+	}
+
+	public void setModify() {
+		Tag	out = getOuterTag();
+		if ( out != null ) {
+			out.set_modify();
+			return;
+		}
+		set_modify();
+	}
+
+	private void getModifiedTag( ArrayList<Tag> list ) {
+		if ( dirty_f ) {
+			list.add( this );
+			return;
+		}
+		Tag[]	tag = getTagArray();
+		for ( int i = 0; i < tag.length; i++ ) {
+			tag[i].getModifiedTag( list );
+		}
+	}
+
+	public Tag[] getModifiedTag() {
+		ArrayList<Tag>	list = new ArrayList<Tag>();
+		getModifiedTag( list );
+		return list.toArray( new Tag[0] );
 	}
 
 	/**
@@ -166,10 +193,14 @@ public class Tag extends HTMLPart {
 
 	private void makeID() {
 		if ( getAttribute( "id" ) != null )	return;
+		if ( "head".equals( getName() ) )	return;
 		long	now = 0;
-		now = tag_id;
-		tag_id++;
-		long	time = (now << 56) | (new Date().getTime() & 0x00ffffffffffffffL);
+		synchronized( PARASELENE_ID ) {
+			now = tag_id;
+			tag_id++;
+		}
+		long	time = (now << 56) ^ (new Date().getTime() & 0x00ffffffffffffffL);
+		time &= 0x7fffffffffffffffL;
 		StringBuilder	buf = new StringBuilder( PARASELENE_ID );
 		buf = buf.append( Long.toString( time, Character.MAX_RADIX ) );
 		setAttribute( new Attribute( "id", buf.toString() ) );
@@ -245,7 +276,8 @@ public class Tag extends HTMLPart {
 	}
 
 	/**
-	 * タグ名の取得。小文字で返す。
+	 * タグ名の取得。<br>
+	 * a や div のようなタグ名を小文字で返します。
 	 * @return タグ名。
 	 */
 	public String getName() {
@@ -358,6 +390,20 @@ public class Tag extends HTMLPart {
 		return (NumberValue)av;
 	}
 
+	/**
+	 * 属性値をURIにして取得。URIValue でない場合、null を返す。<br>
+	 * @param at_name 属性名。
+	 * @return 属性値のURI表現。
+	 */
+	public URI getAttributeToURI( String at_name ) {
+		Attribute	attr = getAttribute( at_name );
+		if ( attr == null )	return null;
+		AttributeValuable	av = attr.get();
+		if ( !(av instanceof URIValue) )	return null;
+		URIValue	u = (URIValue)av;
+		return u.getURI();
+	}
+
 	/**
 	 * HTML文書の追加。name属性値が衝突すると、それを変更します。
 	 * 末尾に追加されます。
@@ -459,7 +505,6 @@ public class Tag extends HTMLPart {
 		doc.add( idx, d );
 		if ( d instanceof Tag ) {
 			Tag tag = (Tag)d;
-			getAssignedPage().nameTag( tag );
 			int	cnt = doc.size();
 			idx = 0;
 			for ( int i = 0; i < cnt; i++ ) {
@@ -470,6 +515,7 @@ public class Tag extends HTMLPart {
 				}
 			}
 			tag_only.add( idx, tag );
+			getAssignedPage().nameTag( tag );
 			if ( tag.getAttribute( "name" ) != null )	makeID();
 			setLocation();
 		}
@@ -980,7 +1026,7 @@ public class Tag extends HTMLPart {
 	 * 内包物の検索。
 	 * 引数で指定されたインスタンス群のうち、this が内包しているもののみを抽出して
 	 * 返します。<br>
-	 * 直接内包ではなく、再帰的にネストされたタグを検索します。
+	 * 直接内包ではなく、再帰的にネストされた要素を検索します。
 	 * @param d 検索対象の集合。
 	 * @return 存在した要素の集合。無ければ空の配列を返します。
 	 */
@@ -998,7 +1044,7 @@ public class Tag extends HTMLPart {
 	 * 内包物の検索。
 	 * 引数で指定されたインスタンス群のうち、this が内包しているもので
 	 * 最初に見つかったものを返します。<br>
-	 * 直接内包ではなく、再帰的にネストされたタグを検索します。
+	 * 直接内包ではなく、再帰的にネストされた要素を検索します。
 	 * @param d 検索対象の集合。
 	 * @return 存在した要素。無ければnullを返します。
 	 */
