@@ -28,13 +28,14 @@ public class ColorMake {
 				new FileInputStream( "../template/color.txt" )
 			)
 		);
+		File	new_file = new File( "../paraselene/WebColor.java" );
 		BufferedWriter	bw = new BufferedWriter(
 			new OutputStreamWriter(
-				new FileOutputStream( "../paraselene/WebColor.java" )
+				new FileOutputStream( new_file )
 			)
 		);
 		SourceHead.init( new File( "../template/head.txt" ) );
-		bw.write( SourceHead.getHead() );
+		bw.write( SourceHead.getHead( new_file ) );
 		bw.write( "package paraselene;\n\n" );
 		bw.write( "/**\n * Web140色定義。\n" );
 		while( true ) {
